@@ -28,6 +28,11 @@
 # include <signal.h>
 #endif
 
+#ifdef HAVE_LOCALE_H
+# include <locale.h>
+#endif
+  
+
 #ifdef ENABLE_NLS
 # include <libintl.h>
 # define _(String) gettext (String) 
@@ -66,6 +71,7 @@
 
 
 /* defines */
+#define BITS4 2
 #define BITS7 1
 #define BITS8 0
 
