@@ -21,21 +21,21 @@
 # include <defines.h>
 #endif
 
+#include "extra.h"
 #include <xmalloc.h>
 #include <lcrypt.h>
 #include <bzero.h>
-#include "extra.h"
-#include "bits.h"
+#include <bits.h>
 #include "locks.h"
 #include <errors.h>
 #include <getpass.h>
+#include <keys.h>
+
 
 extern char* outfile;
 extern int stream_flag;
 extern int cleanDelete;
 
-
-
 char * my_getpass(char * prt) {
 char *atmp;
 char ztmp[MAX_KEY_LEN];
@@ -59,35 +59,49 @@ char *btmp;
 char * get_password(int numofchar,int bitmode,int mode,int type, unsigned int* len)
 {
 int x=0;
-char *tmp;
+char *tmp=NULL;
 char msg[100];
 
-  if (bitmode==0) {
-   sprintf(msg,_("Enter key (%d chars): "),numofchar);
+switch (bitmode) {
+  case BITS8:
+   sprintf(msg,_("Enter key (%d chars): "), numofchar);
 
    if (mode==ENCRYPT) {tmp=my_getpass(msg);} else {tmp=getpass(msg);}
-/*   if (strncmp(tmp,"\0",1)==0) return NULL; */
    if(tmp==NULL) return NULL;
 
    if ((strlen(tmp) < numofchar) && (type!=BLOWFISH)) { fprintf(stderr,_("Warning: keyword is too small for this algorithm\n")); }
    if (strlen(tmp) > numofchar) { fprintf(stderr,_("Warning: Reducing the size of keyword\n")); }
    *len=strlen(tmp);
- }
- else { /* 7bit mode */
-
+   break;
+   
 
+ case BITS7:
    if ( ((numofchar*8) % 7) !=0 ) x=1;
    sprintf(msg,_("Enter key (%d chars): "),((numofchar*8)/7)+x);
 
    if (mode==ENCRYPT) {tmp=my_getpass(msg);} else {tmp=getpass(msg);}
-/*   if (strncmp(tmp,"\0",1)==0) return NULL; */
    if(tmp==NULL) return NULL;
 
    if ((strlen(tmp) < (numofchar*8)/7) && (type!=BLOWFISH)) { fprintf(stderr,_("Warning: keyword is too small for this algorithm\n")); }
    if (strlen(tmp) > ((numofchar*8)/7)+x) { fprintf(stderr,_("Warning: Reducing the size of keyword\n")); }
 
    *len=strip8bit(tmp,strlen(tmp));
-}
+   break;
+
+
+ case BITS4:
+   sprintf(msg,_("Enter key (%d chars): "), numofchar*2);
+
+   if (mode==ENCRYPT) {tmp=my_getpass(msg);} else {tmp=getpass(msg);}
+   if(tmp==NULL) return NULL;
+
+   if ( (strlen(tmp) < numofchar*2) && (type!=BLOWFISH)) 
+       { fprintf(stderr,_("Warning: keyword is too small for this algorithm\n")); }
+
+   *len=strip4bits(tmp,strlen(tmp));
+   break;
+
+ }
 
 return tmp;
 
@@ -114,6 +128,9 @@ char *x=get_algorithms_name(stype);
    case BITS8:
     fprintf (stderr,_( "Keyword Bit Mode: 8bits/char\n"));  
     break;
+   case BITS4:
+    fprintf (stderr,_( "Keyword Bit Mode: 4bits/char\n"));
+    break;
   }
 
    if (ende==ENCRYPT) {
@@ -145,7 +162,7 @@ struct stat ostat;
 #endif
 
 
-int check_file_head(char * filename, unsigned int *algorithm, unsigned int *mode, unsigned int *bit7_flag, unsigned int stream_flag)
+int check_file_head(char * filename, unsigned int *algorithm, unsigned int *mode, unsigned int *bit_flag, unsigned int stream_flag)
 {
 FILE *fstream;
 char buf[6];
@@ -168,7 +185,7 @@ char buf[6];
 
   *algorithm=(unsigned int) buf[3];
   *mode=(unsigned int) buf[4]; 
-  *bit7_flag=(unsigned int) buf[5];
+  *bit_flag=(unsigned int) buf[5];
 
       /* 6 To 9 are crc32 */
 
@@ -196,7 +213,7 @@ char buf[6];
 }
 
 
-int write_file_head(int filedes, unsigned int algorithm, unsigned int mode, unsigned int bit7_flag)
+int write_file_head(int filedes, unsigned int algorithm, unsigned int mode, unsigned int bit_flag)
 {
 unsigned char buf[6];
 
@@ -205,7 +222,7 @@ unsigned char buf[6];
  buf[2]='\0';
  buf[3]=(unsigned char) algorithm;
  buf[4]=(unsigned char) mode; 
- buf[5]=(unsigned char) bit7_flag;
+ buf[5]=(unsigned char) bit_flag;
 
 /* 6 to 9 are crc32 */
 
