@@ -105,7 +105,7 @@ void gaa_help()
 	__gaa_helpsingle('p', "bzip2", "", "Compress before encryption.");
 	__gaa_helpsingle('d', "decrypt", "", "decrypts.");
 	__gaa_helpsingle('x', "hex", "", "Keyword is in hex.");
-	__gaa_helpsingle('i', "bit", "", "keyword bit mode (7 or 8).");
+	__gaa_helpsingle('i', "bit", "", "keyword bit mode (4,7 or 8).");
 	__gaa_helpsingle('u', "unlink", "", "unlink the input file after""encryption/decryption.");
 	__gaa_helpsingle('s', "sunlink", "", "unlink (and destroy) the input file after""encryption/decryption.");
 	__gaa_helpsingle('f', "keyfile", """keyfile"" ", "file to read the keyword from.");
@@ -842,7 +842,7 @@ int gaa(int argc, char **argv, gaainfo *gaaval)
 #line 70 "mcrypt.gaa"
 { gaaval->force=0; gaaval->quiet=1; gaaval->real_random_flag=0; gaaval->config=0;
        gaaval->bare_flag = 0; gaaval->din = 0; gaaval->ein=1; gaaval->hexflag = 0; gaaval->unlink_flag = 0;
-       gaaval->bit = 8; gaaval->keysize=0; gaaval->gzipflag=0; gaaval->bzipflag=0;
+       gaaval->bit = 4; gaaval->keysize=0; gaaval->gzipflag=0; gaaval->bzipflag=0;
        gaaval->sunlink_flag = 0; gaaval->keyfile=NULL; gaaval->algorithm=NULL; gaaval->keys=NULL;
        gaaval->config_file=NULL; gaaval->mode=NULL; gaaval->input=NULL; gaaval->ed_specified=0 ;};
 
@@ -1017,7 +1017,7 @@ int gaa_internal_get_next_str(FILE *file, gaa_str_node *tmp_str, int argc)
     tmp_str->str[i - 1] = 0;
 
     fseek(file,- 1, SEEK_CUR);
-    
+        
     return -1;
 }
 
