@@ -18,13 +18,20 @@
 # define DEFINES_H
 # include <defines.h>
 #endif
+#include <keys.h>
 #include <extra.h>
 #include <lcrypt.h>
 #include <hex.h>
 #include <bzero.h>
 #include <bits.h>
 #include <xmalloc.h>
-void* fixkey(char * key, unsigned int* len, int bit7_flag, int hexflag,int algorithm, int quiet, int stream_flag, int enc_mode) {
+#define rol(x, y) ( (x << y) | (x >> (32 - y)) )
+
+/* fixkey takes the input key (or NULL if it wasn't given) and converts
+ * the key according to the needs (bit_flag)
+ */
+
+void* fixkey(char * key, unsigned int* len, int bit_flag, int hexflag,int algorithm, int quiet, int stream_flag, int enc_mode) {
 
 char *tmp;
 char* keyword;
@@ -39,7 +46,7 @@ int keysize;
   }
  
   if (len!=0) {
-    tmpkey=xmalloc(*len);
+    tmpkey=xmalloc((*len) + 1);
   }
   else {
     tmpkey=xmalloc(MAX_KEY_LEN);
@@ -49,18 +56,18 @@ int keysize;
 
 
   if (key==NULL) {
-    tmp=get_password( keysize, bit7_flag, enc_mode, algorithm , len);
+    tmp=get_password( keysize, bit_flag, enc_mode, algorithm , len);
     if (tmp==NULL) return NULL;
-    *len=strlen(tmp);
 
-    /* If specified in hex and no 7bit */
-        if (hexflag==TRUE && bit7_flag==BITS8) {
+    /* If specified in hex and 8bit */
+        if (hexflag==TRUE && bit_flag==BITS8) {
            *len=hexToChar(tmp, *len);
            if (*len==-1) {
              fprintf(stderr, _("Keyword not in proper hex format\n")); 
              exit(1);
            }
         }
+        
 
         if (*len > keysize) *len=keysize;
         memmove(keyword, tmp, *len);
@@ -71,8 +78,10 @@ int keysize;
 
          memmove(tmpkey, key, *len);
          
-         if (bit7_flag==BITS8) { /* 8bit mode */
 
+  switch (bit_flag) {
+
+    case BITS8:
             /* If specified in hex */
              if (hexflag==TRUE) {
                *len=hexToChar(tmpkey, *len);
@@ -83,30 +92,43 @@ int keysize;
                }
              }
 
-
              if (*len>keysize) {
                 fprintf(stderr,_("Warning: Reducing the size of the key\n"));
                 *len=keysize;
              }
 
              memmove(keyword, tmpkey, *len);
-           }
-
-           else { /* 7bit mode / No hex here */
+             Bzero(tmpkey, *len); /* key is not bzero'd because it may be used again */
+             break;
+         
 
+         case BITS7:
                *len=strip8bit(tmpkey, *len);
-               if (*len > keysize && hexflag==FALSE) {
+               if (*len > keysize) {
                   fprintf(stderr,_("Warning: Reducing the size of the key\n"));
                   *len=keysize;
                }
 
+               memmove(keyword, tmpkey, *len);
+               Bzero(tmpkey, *len); /* key is not bzero'd because it may be used again */
+               break;
+
+
+         case BITS4:
+               *len=strip4bits(tmpkey, *len);
+               if (*len > keysize) {
+                  fprintf(stderr,_("Warning: Reducing the size of the key\n"));
+                  *len=keysize;
+               }
 
                memmove(keyword, tmpkey, *len);
                Bzero(tmpkey, *len); /* key is not bzero'd because it may be used again */
-           }           
-	}
-
+               break;               
+           
+    }
+  } 
 return keyword;
 
 }
 
+
