@@ -30,7 +30,7 @@
 #include <extra.h>
 #include <bits.h>
 #include <lcrypt.h>
-#include <sunlink.h>
+#include <unlink.h>
 #include <crc32.h>
 #include <locks.h>
 #include <enigma.h>
@@ -43,14 +43,13 @@
 #include <swap.h>
 
  char tmperr[128];
- unsigned int bit7_flag, hexflag=FALSE;
+ unsigned int bit_flag, hexflag=FALSE;
  unsigned int stream_flag=FALSE;
  unsigned int mode=CBC; /* 0:cbc 1:ecb */
  unsigned int type=BLOWFISH; /* default: blowfish */
  int quiet=TRUE; /* silent by default */
  int tmpi;
  int unlink_flag=FALSE;
- int sunlink_flag=FALSE; 
  int bare_flag=FALSE, real_random_flag=FALSE;
  int cleanDelete=FALSE;
 #ifdef ZIP
@@ -88,10 +87,9 @@ void usage(char *name)
  -k --key KEY1, KEY2, ...     keyword(s) to use.\n\
  -f --keyfile FILENAME        file to read the keyword from.\n\
  -x --hex                     keyword in hex.\n\
- -i --bit MODE                keyword bit mode. Can be 7 or 8.\n\
+ -i --bit MODE                keyword bit mode. Can be 4, 7 or 8.\n\
+                               (4 is the default)\n\
  -u --unlink                  unlink the input file after encryption/decryption\n\
- -s --sunlink                 unlink and destroy the input file after\n\
-                              encryption/decryption\n\
  -L --license                 displays license information.\n\
  -q --quiet                   suppress some non critical warnings.\n\
  -V --verbose                 some more information is displayed.\n\
@@ -166,7 +164,7 @@ int main(int argc,char **argv)
 #endif 
 
 #ifdef ENABLE_NLS
-  setlocale (LC_ALL, "");
+  setlocale (LC_MESSAGES, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 #endif
@@ -274,26 +272,26 @@ int main(int argc,char **argv)
 		force=info.force;
 		bare_flag=info.bare_flag;
                 unlink_flag=info.unlink_flag;
-                sunlink_flag=info.sunlink_flag;
 		quiet=info.quiet;
                 hexflag=info.hexflag;
 #ifdef ZIP
                 gzipflag=info.gzipflag;
                 bzipflag=info.bzipflag;
 #endif
-                if (info.bit==7) {
-                  if (hexflag==TRUE) 
-                    err_quit(_("Hex mode and 7bit mode are mutually exclusive\n"));
-                  bit7_flag=BITS7;
+                if ((info.bit==7 || info.bit==4) && hexflag==TRUE) {
+                  err_quit(_("Hex mode and 7bit/4bit modes are mutually exclusive\n"));
                 }
                 else {
-                  if (info.bit==8) {
-                    bit7_flag=BITS8; /* default */
-                  }
-                  else {
-                    err_crit(_("Only 7 and 8 bit mode are supported. Assuming 8 bit mode.\n"));
-                    bit7_flag=BITS8; /* default */
-                  }
+                   if (info.bit==8) {
+                       bit_flag=BITS8;
+                   } else {
+                        if (info.bit==4) {
+                          bit_flag=BITS4;
+                        } else {
+                          err_crit(_("Only 4,7 and 8 bit mode are supported. Assuming 4 bit mode.\n"));
+                          bit_flag=BITS4; /* default */
+                        }
+                   }
                 }
               
 
@@ -516,7 +514,7 @@ for(i=0;i<file_count;i++) {
 	if (din==TRUE) {
 
            if (bare_flag==FALSE) {
-             x=check_file_head(file[i],&type,&mode, &bit7_flag, stream_flag);
+             x=check_file_head(file[i],&type,&mode, &bit_flag, stream_flag);
              if (x!=0) {
 
                if (x==-1) {
@@ -581,10 +579,9 @@ for(i=0;i<file_count;i++) {
 # ifdef HAVE_UTIME_H
                            if (stream_flag==FALSE) copyDate(dinfile,outfile);
 # endif
-        	           if (sunlink_flag==TRUE && stream_flag==FALSE) x=safe_unlink(dinfile);
-	        	   if (x!=0) perror("safe_unlink");
 #endif        	           
-        	           if (unlink_flag==TRUE && stream_flag==FALSE) unsafe_unlink(dinfile);
+        	           if (unlink_flag==TRUE && stream_flag==FALSE) x=u_unlink(dinfile);
+        	           if (x!=0) perror("u_unlink");
         	           
         	        }
 	        	else {
@@ -649,10 +646,10 @@ for(i=0;i<file_count;i++) {
 # ifdef HAVE_UTIME_H
                            if (stream_flag==FALSE) copyDate(einfile,outfile);
 # endif
-	        	   if (sunlink_flag==TRUE && stream_flag==FALSE) x=safe_unlink(einfile);
-	        	   if (x!=0) perror("safe_unlink");
 #endif
-	        	   if (unlink_flag==TRUE && stream_flag==FALSE) x=unsafe_unlink(einfile);
+	        	   if (unlink_flag==TRUE && stream_flag==FALSE) x=u_unlink(einfile);
+	        	   if (x!=0) perror("u_unlink");
+
 		       	}
 	                else {
                          if (stream_flag==FALSE) {
@@ -716,7 +713,7 @@ char* command=NULL;
  * It's purpose is to be compatible with the unix crypt which is not safe.
  * It isn't a block algorithm after all.
  */
-  bit7_flag=BITS8;
+  bit_flag=BITS8;
 
   
 /* open files */
@@ -777,7 +774,7 @@ char* command=NULL;
             sprintf(tmperr, _("File: %s\n"),fromfile);
             err_warn (tmperr);
           }
-          tmp=get_password(8, bit7_flag, DECRYPT, type, &len);
+          tmp=get_password(8, bit_flag, DECRYPT, type, &len);
           if (tmp==NULL) return 1;
           memmove(keyword, tmp, len);
           Bzero(tmp, strlen(tmp));
@@ -793,7 +790,7 @@ char* command=NULL;
 	}
 
 
-if (quiet==FALSE) show_mode(ENCRYPT,type,mode,tofile,bit7_flag); 
+if (quiet==FALSE) show_mode(ENCRYPT,type,mode,tofile,bit_flag); 
 
 
   if (unix_setup(keyword)==1) {
@@ -942,7 +939,7 @@ else {
                                                                         
 
   if (bare_flag==FALSE) {
-    write_file_head( fileno((FILE*)TOF), type, mode, bit7_flag);
+    write_file_head( fileno((FILE*)TOF), type, mode, bit_flag);
     write( fileno((FILE*)TOF), ciphertext, blocksize);
      /* Just leave space to put later the crc32 */
   }  
@@ -957,15 +954,15 @@ else {
 
 /* Get keyword */
   if (key==NULL) {
-    keyword=fixkey( NULL, &len, bit7_flag, hexflag, algorithm, quiet, stream_flag, ENCRYPT);
+    keyword=fixkey( NULL, &len, bit_flag, hexflag, algorithm, quiet, stream_flag, ENCRYPT);
   }
   else {
     len=strlen(key);
-    keyword=fixkey( key, &len, bit7_flag, hexflag, algorithm, quiet, stream_flag, ENCRYPT);
+    keyword=fixkey( key, &len, bit_flag, hexflag, algorithm, quiet, stream_flag, ENCRYPT);
   }
  if (keyword==NULL) return 1;
 
- if (quiet==FALSE) show_mode(ENCRYPT,algorithm,mode,tofile,bit7_flag);
+ if (quiet==FALSE) show_mode(ENCRYPT,algorithm,mode,tofile,bit_flag);
 
 
   switch (mode) {
@@ -1293,16 +1290,16 @@ else {
   }
 
   if (key==NULL) {
-    keyword=fixkey( NULL, &len, bit7_flag, hexflag, algorithm, quiet, stream_flag, DECRYPT);
+    keyword=fixkey( NULL, &len, bit_flag, hexflag, algorithm, quiet, stream_flag, DECRYPT);
   }
   else {
     len=strlen(key);
-    keyword=fixkey( key, &len, bit7_flag, hexflag, algorithm, quiet, stream_flag, DECRYPT);
+    keyword=fixkey( key, &len, bit_flag, hexflag, algorithm, quiet, stream_flag, DECRYPT);
   }
   if (keyword==NULL) return 1;
 
 
-  if (quiet==FALSE) show_mode(DECRYPT,algorithm,mode,tofile,bit7_flag);
+  if (quiet==FALSE) show_mode(DECRYPT,algorithm,mode,tofile,bit_flag);
 
   switch (mode) {
     case CBC:
@@ -1678,7 +1675,7 @@ char iv[8];
  * It's purpose is to be compatible with the unix crypt which is not safe.
  * It isn't a block algorithm after all.
  */
-  bit7_flag=BITS8;
+  bit_flag=BITS8;
 
   
 /* open files */
@@ -1739,7 +1736,7 @@ char iv[8];
             sprintf(tmperr, _("File: %s\n"),fromfile);
             err_warn (tmperr);
           }
-          tmp=get_password(8, bit7_flag, DECRYPT, type, &len);
+          tmp=get_password(8, bit_flag, DECRYPT, type, &len);
           if (tmp==NULL) return 1;
           memmove(keyword, tmp, len);
           Bzero(tmp, strlen(tmp));
@@ -1752,7 +1749,7 @@ char iv[8];
 	   memmove(keyword, key, strlen(key)); /* Copy the 64 bits in key */
 	}
 
-       if (quiet==FALSE) show_mode(ENCRYPT,type,mode,tofile,bit7_flag); 
+       if (quiet==FALSE) show_mode(ENCRYPT,type,mode,tofile,bit_flag); 
 
      if (hexflag==FALSE) {
        for(cnt = 0; cnt < 8; cnt++) {
@@ -1850,7 +1847,7 @@ char iv[8];
  * It's purpose is to be compatible with the unix crypt which is not safe.
  * It isn't a block algorithm after all.
  */
-  bit7_flag=BITS8;
+  bit_flag=BITS8;
 
   
 /* open files */
@@ -1911,7 +1908,7 @@ char iv[8];
             sprintf(tmperr, _("File: %s\n"),fromfile);
             err_warn (tmperr);
           }
-          tmp=get_password(8, bit7_flag, DECRYPT, type, &len);
+          tmp=get_password(8, bit_flag, DECRYPT, type, &len);
           if (tmp==NULL) return 1;
           memmove(keyword, tmp, len);
           Bzero(tmp, strlen(tmp));
@@ -1925,7 +1922,7 @@ char iv[8];
 	}
 
 
-if (quiet==FALSE) show_mode(ENCRYPT,type,mode,tofile,bit7_flag); 
+if (quiet==FALSE) show_mode(ENCRYPT,type,mode,tofile,bit_flag); 
 
       if (hexflag==FALSE) {
        for(cnt = 0; cnt < 8; cnt++){
